@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2024  Sutou Kouhei <kou@clear-code.com>
+  Copyright (C) 2024-2025  Sutou Kouhei <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -28,9 +28,9 @@
 namespace grn {
   namespace language_model {
     void
-    init_from_env(void);
+    init_from_env();
     void
-    fin_external_libraries(void);
+    fin_external_libraries();
   } // namespace language_model
 
   class LanguageModelInferencer;
@@ -45,6 +45,8 @@ namespace grn {
 
     std::unique_ptr<LanguageModelInferencer>
     make_inferencer(grn_ctx *ctx);
+    uint32_t
+    get_n_embedding_dimensions(grn_ctx *ctx);
 
   private:
     std::unique_ptr<Impl> impl_;
@@ -55,10 +57,9 @@ namespace grn {
     LanguageModelLoader(grn_ctx *ctx) : ctx_(ctx) {}
 
     std::shared_ptr<LanguageModel>
-    load(void);
+    load();
 
     std::string model_path;
-    int32_t n_gpu_layers = 0;
 
   private:
     grn_ctx *ctx_;
@@ -71,22 +72,43 @@ namespace grn {
     LanguageModelInferencer(Impl *impl);
     ~LanguageModelInferencer();
 
-    /// \brief Generate an embedding for a record
+    /// \brief Prepend `prefix` to all values of `input_column` in
+    ///        \ref vectorize_in_batch.
+    ///
+    /// \param prefix The prefix for all values of `input_column.
+    ///
+    /// \since 15.1.9
     void
-    vectorize(std::string_view text, grn_obj *output_vector);
+    set_input_column_value_prefix(std::string prefix);
+
+    /// \brief Generate an embedding for a record
+    ///
+    /// \param ctx A \ref grn_ctx.
+    /// \param text The text to be vectorized.
+    /// \param output_vector It must be an Float32 vector. This
+    ///                      function doesn't validate it.
+    void
+    vectorize(grn_ctx *ctx, std::string_view text, grn_obj *output_vector);
+
     /// \brief Generate embeddings for multiple records in batch
     ///
+    /// \param ctx A \ref grn_ctx.
     /// \param cursor It must be a valid \ref grn_table_cursor.
     ///               This function doesn't validate it.
     /// \param input_column It must be an text-family scalar
     ///                     column. This function doesn't validate it.
 
-    /// \param output_column It must be an Float32 vector column. This
-    ///                      function doesn't validate it.
+    /// \param output It must be a `Float32` vector column or a
+    ///               `Float32` vector. This function doesn't validate
+    ///               it.
+    ///
+    ///               If it's a `Float32` vector, output order is same
+    ///               as IDs returned by the `cursor`.
     void
-    vectorize_in_batch(grn_table_cursor *cursor,
+    vectorize_in_batch(grn_ctx *ctx,
+                       grn_table_cursor *cursor,
                        grn_obj *input_column,
-                       grn_obj *output_column);
+                       grn_obj *output);
 
   private:
     std::unique_ptr<Impl> impl_;
