@@ -3,7 +3,8 @@
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
-  License version 2.1 as published by the Free Software Foundation.
+  License as published by the Free Software Foundation; either
+  version 2.1 of the License, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,7 +19,7 @@
 #include "grn_romaji.h"
 #include "grn_str.h"
 
-static grn_inline bool
+static inline bool
 grn_romaji_hepburn_is_pbm(const unsigned char *utf8,
                           size_t length)
 {
@@ -73,7 +74,7 @@ grn_romaji_hepburn_is_pbm(const unsigned char *utf8,
   }
 }
 
-static grn_inline bool
+static inline bool
 grn_romaji_hepburn_is_aiueoy(const unsigned char *utf8,
                              size_t length)
 {
@@ -126,7 +127,7 @@ grn_romaji_hepburn_is_aiueoy(const unsigned char *utf8,
   }
 }
 
-static grn_inline unsigned char
+static inline unsigned char
 grn_romaji_hepburn_consonant(grn_ctx *ctx,
                              const unsigned char *current,
                              size_t char_length,
